@@ -55,7 +55,7 @@ loadkernel=load mmc ${mmcdev}:${mmcpart} ${loadaddr} ${snappy_ab}/${kernel_file}
 loadinitrd=load mmc ${mmcdev}:${mmcpart} ${initrd_addr} ${snappy_ab}/${initrd_file}; setenv initrd_size ${filesize}
 loadfdt=load mmc ${mmcdev}:${mmcpart} ${fdtaddr} ${snappy_ab}/dtbs/${fdtfile}
 
-# standard kernel and initrd file names; NB: ftdfile is set early from bootcmd
+# standard kernel and initrd file names; NB: fdtfile is set early from bootcmd
 kernel_file=vmlinuz
 initrd_file=initrd.img
 {{ . }}
@@ -72,7 +72,7 @@ snappy_stamp=snappy-stamp.txt
 snappy_mode=regular
 # if we're trying a new version, check if stamp file is already there to revert
 # to other version
-snappy_boot=if test "${snappy_mode}" = "try"; then if load mmc ${bootpart} ${loadaddr} ${snappy_stamp} 0; then if test "${snappy_ab}" = "a"; then setenv snappy_ab "b"; else setenv snappy_ab "a"; fi; else fatwrite mmc ${mmcdev}:${mmcpart} 0x0 ${snappy_stamp} 0; fi; fi; run loadfiles; setenv mmcroot /dev/disk/by-label/system-${snappy_ab} ${snappy_cmdline}; run mmcargs; bootz ${loadaddr} ${initrd_addr}:${initrd_size} ${fdtaddr}
+snappy_boot=if test "${snappy_mode}" = "try"; then if test -e mmc ${bootpart} ${snappy_stamp}; then if test "${snappy_ab}" = "a"; then setenv snappy_ab "b"; else setenv snappy_ab "a"; fi; else fatwrite mmc ${mmcdev}:${mmcpart} 0x0 ${snappy_stamp} 0; fi; fi; run loadfiles; setenv mmcroot /dev/disk/by-label/system-${snappy_ab} ${snappy_cmdline}; run mmcargs; bootz ${loadaddr} ${initrd_addr}:${initrd_size} ${fdtaddr}
 `
 
 type FlashInstructions struct {
@@ -344,13 +344,13 @@ func (img CoreUBootImage) SetupBoot() error {
 	}
 	defer snappySystemFile.Close()
 
-	var ftdfile string
+	var fdtfile string
 	if img.platform != "" {
-		ftdfile = fmt.Sprintf("ftdfile=%s.dtb", img.platform)
+		fdtfile = fmt.Sprintf("fdtfile=%s.dtb", img.platform)
 	}
 
 	t := template.Must(template.New("snappy-system").Parse(snappySystemTemplate))
-	t.Execute(snappySystemFile, ftdfile)
+	t.Execute(snappySystemFile, fdtfile)
 
 	return nil
 }
